User guide
==========

PyEDB-Core provides an API for accessing and manipulating designs in the EBD format.
Design types managing layout data in AEDT have a corresponding ``aedb`` directory alongside
the AEDT file. The ``aedb`` directory contains the EDB database.

Additionally, EDB databases can be created by Ansys translators or by using the PyEDB-Core
API directly. You can then import the resulting EDB into AEDT.
